==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Klds");
define("_URL","URL");
define("_PRINTER","Nyomtathat vltozat");
define("_FRIEND","Kldd el levlben!");
define("_YOURNAME","Neved");
define("_OK","Ok!");
define("_RELATED","Kapcsold linkek");
define("_MOREABOUT","Adatok:");
define("_NEWSBY","rta:");
define("_MOSTREAD","A legolvasottabb cikk a kvetkez kategriban:");
define("_READMORE","Tovbb...");
define("_BYTESMORE","bet van mg");
define("_COMMENTSQ","rd meg a vlemnyed!");
define("_COMMENT","hozzszls");
define("_CONFIGURE","Belltsok");
define("_LOGINCREATE","Belps/Regisztrci");
define("_THRESHOLD","Kszb");
define("_NOCOMMENTS","Nincs hozzszls!");
define("_NESTED","Begyazott");
define("_FLAT","Sima");
define("_THREAD","Szl");
define("_OLDEST","A legrgebbi fell");
define("_NEWEST","A legrgebbi alul");
define("_HIGHEST","A legolvasottabb fell");
define("_COMMENTSWARNING","Minden hozzszls a szerzk tulajdona. Nem felttlenl rtnk egyet velk, s nem vllalhatunk felelssget a hozzszlsok tartalmrt.");
define("_SCORE","Pontok:");
define("_USERINFO","Adatok");
define("_READREST","A hozzszls folytatsa...");
define("_REPLY","Vlasz");
define("_REPLYMAIN","j hozzszls");
define("_NOSUBJECT","Cm nlkl");
define("_NOANONCOMMENTS","Nvtelenl nem lehet hozzszlni, krjk <a href=\"modules.php?name=Your_Account\">regisztrlj</a>");
define("_PARENT","Szl");
define("_ROOT","Gykr");
define("_UCOMMENT","Hozzszls");
define("_ALLOWEDHTML","Megengedett HTML:");
define("_POSTANON","Nvtelen hozzszls");
define("_EXTRANS","HTML kdok eltvoltsa");
define("_HTMLFORMATED","HTML formzott szveg");
define("_PLAINTEXT","Formzatlan szveg");
define("_ONN","...");
define("_SUBJECT","Cm");
define("_COMMENTREPLY","Hozzszls elkldse");
define("_COMREPLYPRE","Megtekints elklds eltt");
define("_NOTRIGHT","Hiba lpett fel egy vltoz tadsakor. Ez az zenet csak arra szolgl, hogy ksbb ne keveredjenek ssze a dolgok...");
define("_SENDAMSG","zenet kldse");
define("_YOUSENDSTORY","Ezt a cikket:");
define("_TOAFRIEND","a kvetkez bartodnak kldd el:");
define("_FYOURNAME","A te neved:");
define("_FYOUREMAIL","e-mail cmed:");
define("_FFRIENDNAME","Bartod neve:");
define("_FFRIENDEMAIL","Bartod e-mail cme:");
define("_INTERESTING","Egy rdekes cikk innen:");
define("_HELLO","Hell,");
define("_YOURFRIEND","egy bartod");
define("_CONSIDERED","gy vlte, hogy a kvetkez cikk tged is rdekelhet, s ezrt elkldte neked.");
define("_FDATE","Dtum:");
define("_FTOPIC","Tma:");
define("_YOUCANREAD","rdekes cikkeket olvashatsz itt:");
define("_FSTORY","Ezt a cikket:");
define("_HASSENT","elkldtk erre a cmre:");
define("_THANKS","Ksznjk!");
define("_RECOMMEND","Ajnld ezt az oldalt a bartaidnak!");
define("_PDATE","Dtum:");
define("_PTOPIC","Tma:");
define("_COMESFROM","A cikk tulajdonosa:");
define("_THEURL","A cikk webcme:");
define("_PREVIEW","Elnzet");
define("_NEWUSER","j tag");
define("_OPTIONS","Belltsok");
define("_REFRESH","Frissts");
define("_ADD","Hozzads");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Klds");
define("_URL","URL");
define("_PRINTER","Nyomtathat vltozat");
define("_FRIEND","Kldd el levlben!");
define("_YOURNAME","Neved");
define("_OK","Ok!");
define("_RELATED","Kapcsold linkek");
define("_MOREABOUT","Adatok:");
define("_NEWSBY","rta:");
define("_MOSTREAD","A legolvasottabb cikk a kvetkez kategriban:");
define("_READMORE","Tovbb...");
define("_BYTESMORE","bet van mg");
define("_COMMENTSQ","rd meg a vlemnyed!");
define("_COMMENT","hozzszls");
define("_CONFIGURE","Belltsok");
define("_LOGINCREATE","Belps/Regisztrci");
define("_THRESHOLD","Kszb");
define("_NOCOMMENTS","Nincs hozzszls!");
define("_NESTED","Begyazott");
define("_FLAT","Sima");
define("_THREAD","Szl");
define("_OLDEST","A legrgebbi fell");
define("_NEWEST","A legrgebbi alul");
define("_HIGHEST","A legolvasottabb fell");
define("_COMMENTSWARNING","Minden hozzszls a szerzk tulajdona. Nem felttlenl rtnk egyet velk, s nem vllalhatunk felelssget a hozzszlsok tartalmrt.");
define("_SCORE","Pontok:");
define("_USERINFO","Adatok");
define("_READREST","A hozzszls folytatsa...");
define("_REPLY","Vlasz");
define("_REPLYMAIN","j hozzszls");
define("_NOSUBJECT","Cm nlkl");
define("_NOANONCOMMENTS","Nvtelenl nem lehet hozzszlni, krjk <a href=\"modules.php?name=Your_Account\">regisztrlj</a>");
define("_PARENT","Szl");
define("_ROOT","Gykr");
define("_UCOMMENT","Hozzszls");
define("_ALLOWEDHTML","Megengedett HTML:");
define("_POSTANON","Nvtelen hozzszls");
define("_EXTRANS","HTML kdok eltvoltsa");
define("_HTMLFORMATED","HTML formzott szveg");
define("_PLAINTEXT","Formzatlan szveg");
define("_ONN","...");
define("_SUBJECT","Cm");
define("_COMMENTREPLY","Hozzszls elkldse");
define("_COMREPLYPRE","Megtekints elklds eltt");
define("_NOTRIGHT","Hiba lpett fel egy vltoz tadsakor. Ez az zenet csak arra szolgl, hogy ksbb ne keveredjenek ssze a dolgok...");
define("_SENDAMSG","zenet kldse");
define("_YOUSENDSTORY","Ezt a cikket:");
define("_TOAFRIEND","a kvetkez bartodnak kldd el:");
define("_FYOURNAME","A te neved:");
define("_FYOUREMAIL","e-mail cmed:");
define("_FFRIENDNAME","Bartod neve:");
define("_FFRIENDEMAIL","Bartod e-mail cme:");
define("_INTERESTING","Egy rdekes cikk innen:");
define("_HELLO","Hell,");
define("_YOURFRIEND","egy bartod");
define("_CONSIDERED","gy vlte, hogy a kvetkez cikk tged is rdekelhet, s ezrt elkldte neked.");
define("_FDATE","Dtum:");
define("_FTOPIC","Tma:");
define("_YOUCANREAD","rdekes cikkeket olvashatsz itt:");
define("_FSTORY","Ezt a cikket:");
define("_HASSENT","elkldtk erre a cmre:");
define("_THANKS","Ksznjk!");
define("_RECOMMEND","Ajnld ezt az oldalt a bartaidnak!");
define("_PDATE","Dtum:");
define("_PTOPIC","Tma:");
define("_COMESFROM","A cikk tulajdonosa:");
define("_THEURL","A cikk webcme:");
define("_PREVIEW","Elnzet");
define("_NEWUSER","j tag");
define("_OPTIONS","Belltsok");
define("_REFRESH","Frissts");
define("_ADD","Hozzads");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
